/// <reference types="es6-promise" />
/// <reference types="react" />
import * as React from "react";
import { IFormBinding } from "./../binder";
export interface IAutoCompleteOption {
    id: number;
    name: string;
    data?: any;
    className?: string;
}
export interface IAutoCompleteInputProps extends React.Props<AutoCompleteInput> {
    /** (string) CSS classname property */
    className?: string;
    /** (number) No query will get executed until this is met. Defaults to 1 */
    minimumLength?: number;
    /** (string) The text to use a placeholder when no value is present */
    placeholder?: string;
    /** (string) The text show when no results were found */
    noResultsMessage?: string;
    /** (IAutoCompleteOption[]) If you are using local rather than remote options, specify them here */
    options?: IAutoCompleteOption[];
    /** (number) How long to wait after every key press before executing a remote query */
    remoteThrottle?: number;
    /** ((string) => Promise<IAutoCompleteOption[]>) A promise and mapping to IAutoCompleteOption to handle querying remote data */
    remoteQuery?: (query: string) => Promise<IAutoCompleteOption[]>;
    /** (boolean) If set to true, a blank query will be executed as soon as the control is focused */
    remoteQueryOnOpen?: boolean;
    /** (boolean) If set to true, a button will appear along side the box which selects the currently hilighted option on click */
    hasGoButton?: boolean;
    /** (React.ReactElement<any> | string) The content of the go button. Can be text or any element */
    goButtonContent?: React.ReactElement<any> | string;
    /** (number) How many items to show before scrolling. Defaults to 3 */
    visibleItems?: number;
    /** (boolean) If true, shows an X icon to clear selection */
    canClear?: boolean;
    /** (boolean) Wether the control is disabled */
    disabled?: boolean;
    /** (boolean) Wether the control should function like a tagging control, returning an array of options or a single select, returning one option */
    multiSelect?: boolean;
}
export interface IAutoCompleteInputState {
    filteredOptions?: IAutoCompleteOption[];
    query?: string;
    open?: boolean;
    selectedValue?: IAutoCompleteOption | IAutoCompleteOption[];
    selectedIndex?: number;
    remoteSearching?: boolean;
    offsetIndex?: number;
    showOnTop?: boolean;
    topOffset?: number;
}
export declare class AutoCompleteInput extends React.Component<IAutoCompleteInputProps & IFormBinding, IAutoCompleteInputState> {
    private timer;
    private itemHeight;
    static defaultProps: {
        remoteThrottle: number;
        minimumLength: number;
    };
    constructor(props: IAutoCompleteInputProps);
    filterRemote(query: string, immediate?: boolean): void;
    filter(query: string): void;
    focusInput(e: any): void;
    handleEvent(e: any): void;
    componentWillMount(): void;
    componentWillReceiveProps(newProps: IAutoCompleteInputProps & IFormBinding): void;
    shouldShowOnTop(): boolean;
    checkKey(e: any): boolean;
    constrainIndex(): void;
    private isArray<T>(itemOrArray);
    change(value: IAutoCompleteOption[] | IAutoCompleteOption): void;
    handleSelection(options: IAutoCompleteOption | IAutoCompleteOption[]): void;
    buttonClick(): void;
    render(): JSX.Element;
}
